<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Preferences</name>
    <message>
        <source>Retas Level Format</source>
        <translation>Format de niveau Retas</translation>
    </message>
    <message>
        <source>Adobe Photoshop</source>
        <translation>Adobe Photoshop</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No restrictions for uncompressed avi video</source>
        <translation>Aucune restriction pour les fichiers vidéo AVI non compressés</translation>
    </message>
    <message>
        <source>video width must be a multiple of %1</source>
        <translation>La largeur de la vidéo doit être un multiple de %1</translation>
    </message>
    <message>
        <source>video length must be a multiple of %1</source>
        <translation>La longueur de la vidéo doit être un multiple de %1</translation>
    </message>
    <message>
        <source>No restrictions for this codec</source>
        <translation>Aucune restriction pour ce codec</translation>
    </message>
    <message>
        <source>Resolution restrictions:</source>
        <translation>Restrictions sur la résolution :</translation>
    </message>
    <message>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>Impossible de communiquer avec le codec.
 Peut-être que le codec ne fonctionne pas correctement.</translation>
    </message>
    <message>
        <source>%1-%2</source>
        <translation>%1-%2</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>%1 argument(s) attendu(s) pour %2, %3 reçu(s)</translation>
    </message>
    <message>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1 n&apos;est pas une couleur valide (les noms de couleur valides sont «&#xa0;red&#xa0;», «&#xa0;transparent&#xa0;», «&#xa0;#FF8800&#xa0;», etc.)</translation>
    </message>
    <message>
        <source>Vectorization failed</source>
        <translation>Échec de la vectorisation</translation>
    </message>
    <message>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>L&apos;argument ne ressemble pas à un chemin de fichier : %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>Mauvais argument (%1) : il doit s&apos;agir d&apos;une image (non vide)</translation>
    </message>
    <message>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>L&apos;argument «&#xa0;%1&#xa0;» ne ressemble pas à un identifiant d&apos;image</translation>
    </message>
    <message>
        <source>First argument must be a scene : %1</source>
        <translation>Le premier argument doit être une scène : %1</translation>
    </message>
    <message>
        <source>Can&apos;t render empty scene</source>
        <translation>Impossible d&apos;effectuer le rendu d&apos;une scène vide</translation>
    </message>
    <message>
        <source>New Camera  %1</source>
        <translation>Nouvelle caméra %1</translation>
    </message>
    <message>
        <source>New Pegbar  %1</source>
        <translation>Nouveau Pegbar  %1</translation>
    </message>
    <message>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>Définir la caméra active  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Spline  %1</source>
        <translation>Supprimer la ligne de séparation  %1</translation>
    </message>
    <message>
        <source>New Motion Path  %1</source>
        <translation>Nouveau chemin de mouvement  %1</translation>
    </message>
    <message>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>Lier le chemin de mouvement  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Object  %1</source>
        <translation>Supprimer l&apos;objet  %1</translation>
    </message>
    <message>
        <source>Remove Column  </source>
        <translation>Supprimer la colonne  </translation>
    </message>
    <message>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>Charger dans la palette courante  &gt; %1</translation>
    </message>
    <message>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>Remplacer dans la palette courante  &gt; %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette  : %1</source>
        <translation>Supprimer la palette du studio  : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette  : %1</source>
        <translation>Créer une palette de studio  : %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>Supprimer le dossier des palettes de studio : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>Créer un dossier de palettes de studio : %1</translation>
    </message>
    <message>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>Déplacer le dossier de palettes de studio  : %1 : %2  &gt; %3</translation>
    </message>
    <message>
        <source>Arrange Styles  in Palette %1</source>
        <translation>Arranger les styles dans la palette %1</translation>
    </message>
    <message>
        <source>Create Style#%1  in Palette %2</source>
        <translation>Créer le style n°%1 dans la palette %2</translation>
    </message>
    <message>
        <source>Add Style  to Palette %1</source>
        <translation>Ajouter un style à la palette %1</translation>
    </message>
    <message>
        <source>Add Page %1 to Palette %2</source>
        <translation>Ajouter la page %1 à la palette %2</translation>
    </message>
    <message>
        <source>Delete Page %1 from Palette %2</source>
        <translation>Supprimer la page %1 de la palette %2</translation>
    </message>
    <message>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>Charger le modèle de couleur %1 vers la palette %2</translation>
    </message>
    <message>
        <source>Move Page</source>
        <translation>Déplacer la page</translation>
    </message>
    <message>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>Renommer la page  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>Renommer le style n°%1 dans la palette %2  : %3 &gt; %4</translation>
    </message>
    <message>
        <source>Add Fx  : </source>
        <translation>Ajouter un effet  : </translation>
    </message>
    <message>
        <source>Insert Fx  : </source>
        <translation>Insérer un effet  : </translation>
    </message>
    <message>
        <source>Create Linked Fx  : %1</source>
        <translation>Créer un effet lié  : %1</translation>
    </message>
    <message>
        <source>Replace Fx  : </source>
        <translation>Remplacer l&apos;effet  : </translation>
    </message>
    <message>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>Retirer le lien vers l&apos;effet  : %1 - - %2</translation>
    </message>
    <message>
        <source>Make Macro Fx  : %1</source>
        <translation>Créer une macro d&apos;effet  : %1</translation>
    </message>
    <message>
        <source>Explode Macro Fx  : %1</source>
        <translation>Éclater la macro d&apos;effet  : %1</translation>
    </message>
    <message>
        <source>Create Output Fx</source>
        <translation>Créer un effet de sortie</translation>
    </message>
    <message>
        <source>Connect to Xsheet  : </source>
        <translation>Se connecter à Xsheet  : </translation>
    </message>
    <message>
        <source>Disconnect from Xsheet  : </source>
        <translation>Se déconnecter de Xsheet  : </translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Supprimer le lien</translation>
    </message>
    <message>
        <source>Delete Fx Node : %1</source>
        <translation>Supprimer le nœud d&apos;effet : %1</translation>
    </message>
    <message>
        <source>Paste Fx  :  </source>
        <translation>Coller l&apos;effet  :  </translation>
    </message>
    <message>
        <source>Disconnect Fx</source>
        <translation>Déconnecter l&apos;effet</translation>
    </message>
    <message>
        <source>Connect Fx : %1 - %2</source>
        <translation>Connecter l&apos;effet : %1 - %2</translation>
    </message>
    <message>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>Renommer l&apos;effet : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Group Fx</source>
        <translation>Grouper les effets</translation>
    </message>
    <message>
        <source>Ungroup Fx</source>
        <translation>Dégrouper les effets</translation>
    </message>
    <message>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>Renommer le groupe  : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Set Keyframe</source>
        <translation>Définir l&apos;image clé</translation>
    </message>
    <message>
        <source>Remove Keyframe</source>
        <translation>Supprimer l&apos;image clé</translation>
    </message>
    <message>
        <source>Cycle</source>
        <translation>Boucle</translation>
    </message>
    <message>
        <source>The autocentering failed on the current drawing.</source>
        <translation>Échec du centrage automatique sur le dessin courant.</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Déplacer</translation>
    </message>
    <message>
        <source>Edit Rotation</source>
        <translation>Modifier la rotation</translation>
    </message>
    <message>
        <source>Move E/W</source>
        <translation type="vanished">Déplacement E/O</translation>
    </message>
    <message>
        <source>Move N/S</source>
        <translation type="vanished">Déplacement N/S</translation>
    </message>
    <message>
        <source>Move Z</source>
        <translation>Déplacement Z</translation>
    </message>
    <message>
        <source>Edit Stack Order</source>
        <translation>Modifier l&apos;ordre de la pile</translation>
    </message>
    <message>
        <source>Edit Scale W</source>
        <translation>Modifier l&apos;échelle L</translation>
    </message>
    <message>
        <source>Edit Scale H</source>
        <translation>Modifier l&apos;échelle H</translation>
    </message>
    <message>
        <source>Edit Scale</source>
        <translation>Modifier l&apos;échelle</translation>
    </message>
    <message>
        <source>Edit PosPath</source>
        <translation>Modifier le PosPath</translation>
    </message>
    <message>
        <source>Edit Shear X</source>
        <translation type="unfinished">Modifier le cisaillement X</translation>
    </message>
    <message>
        <source>Edit Shear Y</source>
        <translation type="unfinished">Modifier le cisaillement Y</translation>
    </message>
    <message>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  Image : %3</translation>
    </message>
    <message>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>Définir l&apos;image clé   %1 à l&apos;image %2</translation>
    </message>
    <message>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>Supprimer l&apos;image clé   %1 à  l&apos;image %2</translation>
    </message>
    <message>
        <source>Move Center   %1  Frame %2</source>
        <translation type="unfinished">Déplacer le centre   %1  image  %2</translation>
    </message>
    <message>
        <source>color model</source>
        <translation>modèle de couleur</translation>
    </message>
    <message>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation>Définir la position choisie du style n°%1 dans la palette %2 : %3, %4</translation>
    </message>
    <message>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation>Mettre à jour les couleurs à l’aide de positions sélectionnées dans la palette %1</translation>
    </message>
    <message>
        <source>Can&apos;t save</source>
        <translation>Échec de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <source>DarkYellow</source>
        <translation>Jaune foncé</translation>
    </message>
    <message>
        <source>DarkCyan</source>
        <translation>Cyan foncé</translation>
    </message>
    <message>
        <source>DarkMagenta</source>
        <translation>Magenta foncé</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation>Luminosité</translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation>Contraste</translation>
    </message>
    <message>
        <source>HRange</source>
        <translation>Intervalle H</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Largeur de ligne</translation>
    </message>
    <message>
        <source>ColorThres</source>
        <translation>Saturation</translation>
    </message>
    <message>
        <source>WhiteThres</source>
        <translation>Clarté</translation>
    </message>
    <message>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation>Activer / désactiver la palette d&apos;options de peinture automatique : %1  Style n°%2</translation>
    </message>
    <message>
        <source>Can&apos;t undo rename palette</source>
        <translation>Impossible d&apos;annuler renommer la palette</translation>
    </message>
    <message>
        <source>Can&apos;t undo move palette</source>
        <translation>Impossible d&apos;annuler déplacer la palette</translation>
    </message>
    <message>
        <source>Can&apos;t redo rename palette</source>
        <translation>Impossible de rétablir renommer la palette</translation>
    </message>
    <message>
        <source>Can&apos;t redo move palette</source>
        <translation>Impossible de rétablir déplacer la palette</translation>
    </message>
    <message>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation>Renommer la palette de studio : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Xsheet</source>
        <translation>Xsheet</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Chronologie</translation>
    </message>
    <message>
        <source>Failed to save the following resources:
</source>
        <translation>Échec de l&apos;enregistrement des ressources suivantes :
</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and %1 more item(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Purple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Texture</source>
        <comment>TextureStyleChooserPage</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Impossible de vectoriser un niveau %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Impossible de vectoriser un niveau sans images</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Impossible de vectoriser une image %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Mauvais argument (%1) : il doit s&apos;agir d&apos;une image ou d&apos;un niveau</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation>«&#xa0;%1&#xa0;»</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>impossible de concaténer un chemin absolu : %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation>%1 n&apos;est pas un dossier</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation>impossible de lire le contenu du dossier %1</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Le fichier %1 n&apos;existe pas</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation>Prénom de %1 chargé</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation>Erreur inattendue lors de la lecture de l&apos;image</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>Type de fichier non reconnu :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>Impossible d&apos;enregistrer une image %1 vers ce type de fichier : %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation>Erreur inattendue lors de l&apos;écriture de l&apos;image</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>Mauvais argument (%1) : doit prendre la valeur «&#xa0;Raster&#xa0;» ou «&#xa0;ToonzRaster&#xa0;»</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation>Constructeur d&apos;images (image %1)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>Mauvais argument (%1) : il doit s&apos;agir d&apos;une transformation</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <source>%1 frames</source>
        <translation>%1 images</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>Mauvais argument (%1). Il doit s&apos;agir d&apos;un chemin de fichiers ou d&apos;une chaîne de caractères</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation>Exception levée lors du chargement du niveau (%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Le fichier %1 n&apos;existe pas</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation>Le fichier %1 n&apos;est pas pris en charge</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>Exception levée lors de la lecture de %1</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation>Impossible d&apos;enregistrer un niveau vide</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>Type de fichier non reconnu :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>Impossible d&apos;enregistrer un niveau %1 vers ce type de fichier : %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>Exception levée lors de l&apos;écriture de %1</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation>le numéro d&apos;image (%1) doit être un nombre</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>le numéro d&apos;image (%1) est hors bornes (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation>le deuxième argument (%1) n&apos;est pas une image</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation>impossible d&apos;insérer une image %1 dans un niveau</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>impossible d&apos;insérer une image %1 dans un niveau %2</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Impossible de vectoriser un niveau %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Impossible de vectoriser un niveau sans images</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Impossible de vectoriser une image %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Mauvais argument (%1) : il doit s&apos;agir d&apos;une image ou d&apos;un niveau</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation>Couleur invalide : </translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation>Une image vectorielle était attendue : %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation>Un niveau vectoriel était attendu : %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation>L&apos;argument doit être un niveau ou une image vectorielle : </translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation>%1 n&apos;a aucune palette</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Le fichier %1 n&apos;existe pas</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>Exception levée lors de la lecture de %1</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>Exception levée lors de l&apos;écriture de %1</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>Mauvais type de niveau (%1) : doit être défini à «&#xa0;Vector&#xa0;», «&#xa0;Raster&#xa0;» ou «ToonzRaster&#xa0;&#xa0;»</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>Impossible d&apos;ajouter le niveau : le nom (%1) est déjà utilisé</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>Impossible de charger ce type de fichier comme niveau : %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation>Impossible de charger le niveau %1</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation>Le niveau n&apos;est pas inclus dans la scène : %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1 : Une instance ou un nom de niveau est attendu</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>Le niveau «&#xa0;%1&#xa0;» n&apos;est pas inclus dans la scène</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation>Impossible de convertir un niveau %1</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>Impossible de convertir un niveau sans images</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation>Impossible de convertir une image %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>Mauvais argument (%1) : il doit s&apos;agir d&apos;un niveau Raster ou d&apos;une image raster</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation>Translation (%1, %2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation>Rotation (%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation>Échelle (%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation>Échelle (%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>Transformation (%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
